import { Button } from '@material-ui/core'
import defaultIcon from 'assets/icons/visu/ecogesture/default.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import EcogestureModal from 'components/Ecogesture/EcogestureModal/EcogestureModal'
import { Ecogesture } from 'models'
import React, { useCallback, useEffect, useState } from 'react'
import { importIconById } from 'utils/utils'
import './actionCard.scss'

interface ActionCardProps {
  action: Ecogesture
  setSelectedAction: React.Dispatch<React.SetStateAction<Ecogesture | null>>
  setShowList: React.Dispatch<React.SetStateAction<boolean>>
  setFocus: () => void
}

const ActionCard = ({
  action,
  setSelectedAction,
  setShowList,
  setFocus,
}: ActionCardProps) => {
  const [actionIcon, setActionIcon] = useState<string>('')
  const [openEcogestureModal, setOpenEcogestureModal] = useState<boolean>(false)

  const selectEcogesture = useCallback(() => {
    setSelectedAction(action)
    setShowList(false)
    setOpenEcogestureModal(false)
    setFocus()
  }, [setSelectedAction, action, setShowList, setFocus])

  useEffect(() => {
    async function handleEcogestureIcon() {
      const icon = await importIconById(action.id, 'ecogesture')
      setActionIcon(icon || defaultIcon)
    }
    handleEcogestureIcon()
  }, [action])

  return (
    <>
      {action && (
        <Button
          key={action.id}
          className="action-card"
          onClick={() => setOpenEcogestureModal(true)}
        >
          <StyledIcon className="action-icon" icon={actionIcon} size={100} />
          <div className="action-title text-18-bold">{action.shortName}</div>
        </Button>
      )}
      {action && (
        <EcogestureModal
          open={openEcogestureModal}
          ecogesture={action}
          isAction={true}
          handleCloseClick={() => setOpenEcogestureModal(false)}
          selectEcogesture={selectEcogesture}
        />
      )}
    </>
  )
}

export default ActionCard
