import { render, screen, waitFor } from '@testing-library/react'
import { FluidType } from 'enums'
import React from 'react'
import { Provider } from 'react-redux'
import { graphData } from 'tests/__mocks__/chartData.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import MaxConsumptionCard from './MaxConsumptionCard'

const mockGetGraphData = jest.fn(() => graphData)
jest.mock('services/consumption.service', () => {
  return jest.fn(() => ({
    getMaxLoad: jest.fn(() => 0),
    getGraphData: mockGetGraphData,
  }))
})

describe('MaxConsumptionCard component', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly with 2 buttons', async () => {
    const { container } = render(
      <Provider store={store}>
        <MaxConsumptionCard
          fluidsWithData={[FluidType.ELECTRICITY, FluidType.GAS]}
        />
      </Provider>
    )
    await waitFor(() => null, { container })
    expect(container).toMatchSnapshot()
    const fluidButtons = screen.getAllByRole('tab')
    expect(fluidButtons).toHaveLength(2)
  })
})
