import Coin from 'assets/icons/ico/coin.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useClient } from 'cozy-client'
import { FluidType, TimeStep } from 'enums'
import { Dataload } from 'models'
import React, { useCallback, useEffect, useState } from 'react'
import ConsumptionService from 'services/consumption.service'
import ConverterService from 'services/converter.service'
import { useAppSelector } from 'store/hooks'
import { convertDateToShortDateString } from 'utils/date'
import { formatNumberValues } from 'utils/utils'
import './consumptionDetails.scss'

const ConsumptionDetails = ({ fluidType }: { fluidType: FluidType }) => {
  const client = useClient()
  const { currentTimeStep, currentDatachart } = useAppSelector(
    state => state.ecolyo.chart
  )

  const [totalValue, setTotalValue] = useState<string>('-----')

  const computeTotal = useCallback(
    async (
      dataload: Dataload[],
      setState: React.Dispatch<React.SetStateAction<string>>
    ) => {
      const consumptionService = new ConsumptionService(client)
      const activateHalfHourLoad =
        fluidType === FluidType.ELECTRICITY
          ? await consumptionService.checkDoctypeEntries(
              FluidType.ELECTRICITY,
              TimeStep.HALF_AN_HOUR
            )
          : false

      const converterService = new ConverterService()
      let total = 0
      let totalPrice = 0

      dataload.forEach(data => {
        if (data.value !== -1) {
          total += data.value
          totalPrice += converterService.LoadToEuro(
            data.value,
            fluidType,
            data.price
          )
        }
      })

      let displayedValue
      if (
        total <= 0 ||
        (!activateHalfHourLoad &&
          currentTimeStep === TimeStep.HALF_AN_HOUR &&
          fluidType === FluidType.ELECTRICITY)
      ) {
        displayedValue = '-----'
      } else if (fluidType === FluidType.MULTIFLUID) {
        displayedValue = formatNumberValues(total).toString()
      } else if (totalPrice <= 0) {
        displayedValue = formatNumberValues(
          converterService.LoadToEuro(total, fluidType)
        ).toString()
      } else {
        displayedValue = formatNumberValues(totalPrice).toString()
      }

      setState(displayedValue)
    },
    [client, currentTimeStep, fluidType]
  )

  useEffect(() => {
    let subscribed = true
    const fetchTotal = async () => {
      await computeTotal(currentDatachart.actualData, setTotalValue)
    }
    subscribed && fetchTotal()
    return () => {
      subscribed = false
    }
  }, [currentDatachart, fluidType, currentTimeStep, client, computeTotal])

  return (
    <div className="consumption-details-root">
      <div className="consumption-details-content">
        <div className="text-18-normal">
          {convertDateToShortDateString(
            currentDatachart.actualData,
            currentTimeStep
          )}
        </div>
        <div className="icon-line">
          <StyledIcon className="euro-icon" icon={Coin} size={32} />
          <div>
            <span className="euro-value">{totalValue}</span>
            <span className="euro-symbol"> €</span>
          </div>
        </div>
      </div>
    </div>
  )
}

export default ConsumptionDetails
