import LeftArrowIcon from 'assets/icons/ico/left-arrow.svg'
import RightArrowIcon from 'assets/icons/ico/right-arrow.svg'
import classNames from 'classnames'
import StyledIconButton from 'components/CommonKit/IconButton/StyledIconButton'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import { TimeStep } from 'enums'
import { DateTime } from 'luxon'
import React from 'react'
import { formatDate } from 'utils/date'
import './datenavigator.scss'

interface DateNavigatorProps {
  disableNext: boolean
  disablePrev: boolean
  handleNextDate: () => void
  handlePrevDate: () => void
  inlineDateDisplay?: boolean
  navigatorDate: DateTime
  timeStep: TimeStep
}

const DateNavigator = ({
  disableNext,
  disablePrev,
  handleNextDate,
  handlePrevDate,
  inlineDateDisplay = false,
  navigatorDate,
  timeStep,
}: DateNavigatorProps) => {
  const { t } = useI18n()
  const formattedDate = formatDate(timeStep, navigatorDate)

  return (
    <div
      role="group"
      aria-label={t('consumption.accessibility.navigation_group')}
      className="date-navigator"
    >
      <StyledIconButton
        icon={LeftArrowIcon}
        onClick={handlePrevDate}
        disabled={disablePrev}
        aria-label={t('consumption.accessibility.button_previous_value')}
        className={classNames('date-navigator-button', {
          disable: disablePrev,
        })}
      />

      <div className="date-navigator-format">
        {inlineDateDisplay && formattedDate[0] && formattedDate[1] && (
          <div className="date-navigator-format-date text-16-bold">
            {formattedDate[0]} {formattedDate[1]}
          </div>
        )}
        {!inlineDateDisplay && (
          <>
            {formattedDate[0] && (
              <div className="date-navigator-format-date text-16-bold timeRange">
                {formattedDate[0]}
              </div>
            )}
            {formattedDate[1] && (
              <div className="date-navigator-format-date text-15-normal">
                {formattedDate[1]}
              </div>
            )}
          </>
        )}
      </div>

      <StyledIconButton
        icon={RightArrowIcon}
        onClick={handleNextDate}
        disabled={disableNext}
        aria-label={t('consumption.accessibility.button_next_value')}
        className={classNames('date-navigator-button', {
          disable: disableNext,
        })}
      />
    </div>
  )
}

export default DateNavigator
