import { Client } from 'cozy-client'
import { FluidType } from 'enums'
import AccountService from 'services/account.service'
import ConfigService from 'services/fluidConfig.service'

export default class KonnectorStatusService {
  private _client: Client

  constructor(_client: Client) {
    this._client = _client
  }

  /**
   * Return a FluidType array containing each konnector fluid with a account
   * @returns {Promise<FluidType[]>} configured FluidTypes array
   */
  async getKonnectorAccountStatus(): Promise<FluidType[]> {
    const fluidConfig = new ConfigService().getFluidConfig()
    const accountService = new AccountService(this._client)
    const [elecData, waterData, gasData] = await Promise.all([
      accountService.getAccountByType(
        fluidConfig[FluidType.ELECTRICITY].konnectorConfig.slug
      ),
      accountService.getAccountByType(
        fluidConfig[FluidType.WATER].konnectorConfig.slug
      ),
      accountService.getAccountByType(
        fluidConfig[FluidType.GAS].konnectorConfig.slug
      ),
    ])
    const data: FluidType[] = []
    if (elecData) {
      data.push(fluidConfig[FluidType.ELECTRICITY].fluidTypeId)
    }
    if (waterData) {
      data.push(fluidConfig[FluidType.WATER].fluidTypeId)
    }
    if (gasData) {
      data.push(fluidConfig[FluidType.GAS].fluidTypeId)
    }
    return data
  }
}
