import { EquipmentType, FluidType, Room, Season, Usage } from 'enums'
import { Ecogesture } from 'models'

export const mockedEcogesturesData: Ecogesture[] = [
  {
    fluidTypes: [FluidType.ELECTRICITY, FluidType.GAS],
    id: 'ECOGESTURE001',
    longDescription:
      'On se demande parfois si cela vaut le coup de "couper le chauffage" quand on s’absente… dès qu’il s’agit d’un week-end la réponse est « oui sûrement » ! Attention cependant au retour à ne pas faire de la surchauffe ! L’idéal est bien évidemment de régler sa programmation pour que le chauffage se relance quelques heures avant votre retour…',
    longName:
      "Je baisse le chauffage en mode hors gel lorsque je m'absente plus de 2 jours.",
    shortName: 'Bonhomme de neige',
    usage: Usage.HEATING,
    impactLevel: 8,
    efficiency: 4,
    difficulty: 1,
    room: [Room.ALL],
    season: Season.WINTER,
    equipment: false,
    equipmentType: [],
    equipmentInstallation: true,
    investment: null,
    action: false,
    actionName: null,
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: 'ECOGESTURE001',
    _rev: '1-67f1ea36efdd892c96bf64a8943154cd',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
  {
    fluidTypes: [FluidType.ELECTRICITY],
    id: 'ECOGESTURE002',
    longDescription:
      "Cela permet de garder la fraîcheur à l'intérieur. Le climatiseur n'est pas là pour refroidir la rue mais bien la pièce.",
    longName: 'Je ferme mes fenêtres quand la climatisation est en marche',
    shortName: 'Coup de vent',
    usage: Usage.AIR_CONDITIONING,
    impactLevel: 8,
    efficiency: 4,
    difficulty: 1,
    room: [Room.ALL],
    season: Season.SUMMER,
    equipment: true,
    equipmentType: [EquipmentType.AIR_CONDITIONING],
    equipmentInstallation: true,
    investment: null,
    action: false,
    actionName: null,
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: 'ECOGESTURE002',
    _rev: '1-ef7ddd778254e3b7d331a88fd17f606d',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
  {
    fluidTypes: [FluidType.WATER],
    id: 'ECOGESTURE0013',
    longDescription:
      "Utilisez la température la plus basse possible : de nombreux produits nettoyants sont efficaces à froid et un cycle à 90 °C consomme 3 fois plus d'énergie qu'un lavage à 40 °C. En effet, 80 % de l'énergie consommée par un lave-linge ou un lave-vaisselle sert au chauffage de l'eau ! Que ce soit pour la vaisselle ou le linge, les programmes de lavage intensif consomment jusqu'à 40 % de plus. Si possible, rincez à l'eau froide : la température de rinçage n'a pas d'effet sur le nettoyage du linge ou de la vaisselle. Attention cependant avec les tissus qui peuvent rétrécir : ce qui fait rétrécir, c'est le passage d'une température à une autre. Mieux vaut alors faire le cycle complet à l'eau froide pour les premiers lavages de tissus sensibles. Pour du linge ou de la vaisselle peu sales, utilisez la touche \"Eco\". Elle réduit la température de lavage et allonge sa durée (c’est le chauffage de l’eau qui consomme le plus). Vous économiserez jusqu’à 45 % par rapport aux cycles longs. Néanmoins, pour vous prémunir contre les bouchons de graisse dans les canalisations, faites quand même un cycle à chaud une fois par mois environ.",
    longName:
      'J’utilise le plus souvent les cycles courts à basse température pour laver le linge et la vaisselle.',
    shortName: 'Accélérateur de particules',
    usage: Usage.ELECTRICITY_SPECIFIC,
    impactLevel: 2,
    efficiency: 1,
    difficulty: 1,
    room: [Room.BATHROOM, Room.LAUNDRY, Room.KITCHEN],
    season: Season.NONE,
    equipment: false,
    equipmentType: [EquipmentType.WASHING_MACHINE, EquipmentType.DISHWASHER],
    equipmentInstallation: true,
    investment: null,
    action: true,
    actionName:
      'J’utilise le cycle court à basse température pour laver le linge et la vaisselle.',
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: 'ECOGESTURE0013',
    _rev: '1-0b2761dd4aef79556c7aef144060fde6',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
]

export const mockDoingEcogestures: Ecogesture[] = [
  { ...mockedEcogesturesData[0], doing: true, viewedInSelection: true },
  { ...mockedEcogesturesData[1], doing: false, viewedInSelection: true },
  { ...mockedEcogesturesData[2], doing: true, viewedInSelection: true },
]

export const mockedEcogesturesSortedData: Ecogesture[] = [
  {
    fluidTypes: [FluidType.ELECTRICITY],
    id: 'ECOGESTURE0002',
    longDescription:
      "Cela permet de garder la fraîcheur à l'intérieur. Le climatiseur n'est pas là pour refroidir la rue mais bien la pièce.",
    longName: 'Je ferme mes fenêtres quand la climatisation est en marche',
    shortName: 'Portique thermique',
    usage: Usage.AIR_CONDITIONING,
    impactLevel: 8,
    efficiency: 4,
    difficulty: 1,
    room: [Room.ALL],
    season: Season.SUMMER,
    equipment: true,
    equipmentType: [EquipmentType.AIR_CONDITIONING],
    equipmentInstallation: true,
    investment: null,
    action: false,
    actionName: null,
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: 'ECOGESTURE0002',
    _rev: '19-9b604bcf7e55f8650e2be4f676fddaf0',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
  {
    fluidTypes: [FluidType.ELECTRICITY],
    id: 'ECOGESTURE0035',
    longDescription:
      'Réglez votre climatisation au plus bas à 26 °C et veillez à ce qu’il n’y ait jamais plus de 5 à 7 °C de différence entre l’intérieur et l’extérieur. Attention aux grands écarts de température qui peuvent provoquer des chocs thermiques.',
    longName:
      'Je règle ma climatisation au plus bas à 26°C en veillant à ce qu’il n’y ait pas jamais plus de 5°C à 7°C de différence entre l’intérieur et l’extérieur.',
    shortName: "La Juste Clim'",
    usage: Usage.AIR_CONDITIONING,
    impactLevel: 8,
    efficiency: 4,
    difficulty: 2,
    room: [Room.ALL],
    season: Season.SUMMER,
    equipment: true,
    equipmentType: [EquipmentType.AIR_CONDITIONING],
    equipmentInstallation: true,
    investment: null,
    action: false,
    actionName: null,
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: 'ECOGESTURE0035',
    _rev: '17-666648f24f6c797443470a54785322c5',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
  {
    fluidTypes: [FluidType.ELECTRICITY],
    id: 'ECOGESTURE0034',
    longDescription:
      "Cela permet d'évite des consommations inutiles. Le froid ne restera pas dans la pièce. Donc il est préférable d'allumer le ventilateur ou climatiseur seulement quand des personnes sont présentes dans la pièce.",
    longName:
      'Je ne fais pas fonctionner mon ventilateur ou la climatisation dans les pièces non occupées',
    shortName: 'Bulles-à-part',
    usage: Usage.AIR_CONDITIONING,
    impactLevel: 8,
    efficiency: 4,
    difficulty: 2,
    room: [Room.ALL],
    season: Season.SUMMER,
    equipment: true,
    equipmentType: [EquipmentType.AIR_CONDITIONING, EquipmentType.FAN],
    equipmentInstallation: true,
    investment: null,
    action: false,
    actionName: null,
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: 'ECOGESTURE0034',
    _rev: '25-75810c7b375dcf2742f0b225fda7c6d6',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
]

export const ecogesturesHeatingData: Ecogesture[] = [
  {
    fluidTypes: [FluidType.ELECTRICITY],
    id: 'ECOGESTURE001',
    longDescription:
      'On se demande parfois si cela vaut le coup de "couper le chauffage" quand on s’absente… dès qu’il s’agit d’un week-end la réponse est « oui sûrement » ! Attention cependant au retour à ne pas faire de la surchauffe ! L’idéal est bien évidemment de régler sa programmation pour que le chauffage se relance quelques heures avant votre retour…',
    longName:
      "Je baisse le chauffage en mode hors gel lorsque je m'absente plus de 2 jours.",
    shortName: 'Bonhomme de neige',
    usage: Usage.HEATING,
    impactLevel: 8,
    efficiency: 4,
    difficulty: 1,
    room: [Room.ALL],
    season: Season.WINTER,
    equipment: false,
    equipmentType: [],
    equipmentInstallation: true,
    investment: null,
    action: false,
    actionName: null,
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: 'ECOGESTURE001',
    _rev: '1-67f1ea36efdd892c96bf64a8943154cd',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
  {
    fluidTypes: [FluidType.GAS],
    id: 'ECOGESTURE002',
    longDescription:
      "Cela permet de garder la fraîcheur à l'intérieur. Le climatiseur n'est pas là pour refroidir la rue mais bien la pièce.",
    longName: 'Je ferme mes fenêtres quand la climatisation est en marche',
    shortName: 'Coup de vent',
    usage: Usage.HEATING,
    impactLevel: 8,
    efficiency: 4,
    difficulty: 1,
    room: [Room.ALL],
    season: Season.SUMMER,
    equipment: true,
    equipmentType: [EquipmentType.AIR_CONDITIONING],
    equipmentInstallation: true,
    investment: null,
    action: false,
    actionName: null,
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: 'ECOGESTURE002',
    _rev: '1-ef7ddd778254e3b7d331a88fd17f606d',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
  {
    fluidTypes: [FluidType.ELECTRICITY, FluidType.GAS],
    id: 'ECOGESTURE0013',
    longDescription:
      "Utilisez la température la plus basse possible : de nombreux produits nettoyants sont efficaces à froid et un cycle à 90 °C consomme 3 fois plus d'énergie qu'un lavage à 40 °C. En effet, 80 % de l'énergie consommée par un lave-linge ou un lave-vaisselle sert au chauffage de l'eau ! Que ce soit pour la vaisselle ou le linge, les programmes de lavage intensif consomment jusqu'à 40 % de plus. Si possible, rincez à l'eau froide : la température de rinçage n'a pas d'effet sur le nettoyage du linge ou de la vaisselle. Attention cependant avec les tissus qui peuvent rétrécir : ce qui fait rétrécir, c'est le passage d'une température à une autre. Mieux vaut alors faire le cycle complet à l'eau froide pour les premiers lavages de tissus sensibles. Pour du linge ou de la vaisselle peu sales, utilisez la touche \"Eco\". Elle réduit la température de lavage et allonge sa durée (c’est le chauffage de l’eau qui consomme le plus). Vous économiserez jusqu’à 45 % par rapport aux cycles longs. Néanmoins, pour vous prémunir contre les bouchons de graisse dans les canalisations, faites quand même un cycle à chaud une fois par mois environ.",
    longName:
      'J’utilise le plus souvent les cycles courts à basse température pour laver le linge et la vaisselle.',
    shortName: 'Accelerateur de particules',
    usage: Usage.HEATING,
    impactLevel: 2,
    efficiency: 1,
    difficulty: 1,
    room: [Room.BATHROOM, Room.LAUNDRY, Room.KITCHEN],
    season: Season.NONE,
    equipment: true,
    equipmentType: [EquipmentType.WASHING_MACHINE, EquipmentType.DISHWASHER],
    equipmentInstallation: true,
    investment: null,
    action: true,
    actionName:
      'J’utilise le cycle court à basse température pour laver le linge et la vaisselle.',
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: 'ECOGESTURE0013',
    _rev: '1-0b2761dd4aef79556c7aef144060fde6',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
]

export const ecogesturesECSData: Ecogesture[] = [
  {
    fluidTypes: [FluidType.ELECTRICITY],
    id: 'ECOGESTURE001',
    longDescription:
      'On se demande parfois si cela vaut le coup de "couper le chauffage" quand on s’absente… dès qu’il s’agit d’un week-end la réponse est « oui sûrement » ! Attention cependant au retour à ne pas faire de la surchauffe ! L’idéal est bien évidemment de régler sa programmation pour que le chauffage se relance quelques heures avant votre retour…',
    longName:
      "Je baisse le chauffage en mode hors gel lorsque je m'absente plus de 2 jours.",
    shortName: 'Bonhomme de neige',
    usage: Usage.ECS,
    impactLevel: 8,
    efficiency: 4,
    difficulty: 1,
    room: [Room.ALL],
    season: Season.WINTER,
    equipment: false,
    equipmentType: [],
    equipmentInstallation: true,
    investment: null,
    action: false,
    actionName: null,
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: 'ECOGESTURE001',
    _rev: '1-67f1ea36efdd892c96bf64a8943154cd',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
  {
    fluidTypes: [FluidType.GAS],
    id: 'ECOGESTURE002',
    longDescription:
      "Cela permet de garder la fraîcheur à l'intérieur. Le climatiseur n'est pas là pour refroidir la rue mais bien la pièce.",
    longName: 'Je ferme mes fenêtres quand la climatisation est en marche',
    shortName: 'Coup de vent',
    usage: Usage.ECS,
    impactLevel: 8,
    efficiency: 4,
    difficulty: 1,
    room: [Room.ALL],
    season: Season.SUMMER,
    equipment: true,
    equipmentType: [EquipmentType.AIR_CONDITIONING],
    equipmentInstallation: true,
    investment: null,
    action: false,
    actionName: null,
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: 'ECOGESTURE002',
    _rev: '1-ef7ddd778254e3b7d331a88fd17f606d',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
  {
    fluidTypes: [FluidType.ELECTRICITY, FluidType.GAS],
    id: 'ECOGESTURE0013',
    longDescription:
      "Utilisez la température la plus basse possible : de nombreux produits nettoyants sont efficaces à froid et un cycle à 90 °C consomme 3 fois plus d'énergie qu'un lavage à 40 °C. En effet, 80 % de l'énergie consommée par un lave-linge ou un lave-vaisselle sert au chauffage de l'eau ! Que ce soit pour la vaisselle ou le linge, les programmes de lavage intensif consomment jusqu'à 40 % de plus. Si possible, rincez à l'eau froide : la température de rinçage n'a pas d'effet sur le nettoyage du linge ou de la vaisselle. Attention cependant avec les tissus qui peuvent rétrécir : ce qui fait rétrécir, c'est le passage d'une température à une autre. Mieux vaut alors faire le cycle complet à l'eau froide pour les premiers lavages de tissus sensibles. Pour du linge ou de la vaisselle peu sales, utilisez la touche \"Eco\". Elle réduit la température de lavage et allonge sa durée (c’est le chauffage de l’eau qui consomme le plus). Vous économiserez jusqu’à 45 % par rapport aux cycles longs. Néanmoins, pour vous prémunir contre les bouchons de graisse dans les canalisations, faites quand même un cycle à chaud une fois par mois environ.",
    longName:
      'J’utilise le plus souvent les cycles courts à basse température pour laver le linge et la vaisselle.',
    shortName: 'Accelerateur de particules',

    usage: Usage.ECS,
    efficiency: 1,
    difficulty: 1,
    room: [Room.BATHROOM, Room.LAUNDRY, Room.KITCHEN],
    season: Season.NONE,
    impactLevel: 2,
    equipment: true,
    equipmentType: [EquipmentType.WASHING_MACHINE, EquipmentType.DISHWASHER],
    equipmentInstallation: true,
    investment: null,
    action: true,
    actionName:
      'J’utilise le cycle court à basse température pour laver le linge et la vaisselle.',
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: 'ECOGESTURE0013',
    _rev: '1-0b2761dd4aef79556c7aef144060fde6',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
]

export const BoilerEcogesture: Ecogesture[] = [
  {
    fluidTypes: [FluidType.ELECTRICITY, FluidType.WATER],
    id: '0046',
    longDescription:
      "Pourquoi continuer à chauffer de l’eau lorsqu’on n’est pas là pour l’utiliser ? Si vous possédez un chauffe-eau à accumulation et que vous partez plusieurs jours, il peut être utile de le couper car il continuera de consommer pour maintenir l’eau à température. Attention cependant à la douche froide du retour, n'oubliez de le remettre en marche en rentrant !",
    longName: 'Je coupe mon chauffe-eau dès que je pars plus de 4 jours.',
    shortName: 'Déesse du feu',
    usage: Usage.ALL,
    impactLevel: 6,
    efficiency: 3,
    difficulty: 2,
    room: [Room.ALL],
    season: Season.WINTER,
    equipment: true,
    equipmentType: [EquipmentType.BOILER],
    equipmentInstallation: true,
    investment: null,
    action: false,
    actionName: null,
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: '001',
    _rev: '1-67f1ea36efdd892c96bf64a8943154cd',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
]
export const BoilerEcogestureFalse: Ecogesture[] = [
  {
    fluidTypes: [FluidType.ELECTRICITY, FluidType.WATER],
    id: '0046',
    longDescription:
      "Pourquoi continuer à chauffer de l’eau lorsqu’on n’est pas là pour l’utiliser ? Si vous possédez un chauffe-eau à accumulation et que vous partez plusieurs jours, il peut être utile de le couper car il continuera de consommer pour maintenir l’eau à température. Attention cependant à la douche froide du retour, n'oubliez de le remettre en marche en rentrant !",
    longName: 'Je coupe mon chauffe-eau dès que je pars plus de 4 jours.',
    shortName: 'Déesse du feu',
    usage: Usage.ALL,
    impactLevel: 6,
    efficiency: 3,
    difficulty: 2,
    room: [Room.ALL],
    season: Season.WINTER,
    equipment: false,
    equipmentType: [EquipmentType.BOILER],
    equipmentInstallation: true,
    investment: null,
    action: false,
    actionName: null,
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
    _id: '001',
    _rev: '1-67f1ea36efdd892c96bf64a8943154cd',
    _type: 'com.grandlyon.ecolyo.ecogesture',
  },
]
